export type Bridge = {
    "version": "0.2.0";
    "name": "bridge";
    "instructions": [
        {
            "name": "initializeBridgeV1";
            "accounts": [
                {
                    "name": "owner";
                    "isMut": true;
                    "isSigner": true;
                    "docs": [
                        "Whoever initializes the config will be the owner of the program. Signer",
                        "for creating the [`SenderConfig`] and [`RedeemerConfig`] accounts."
                    ];
                },
                {
                    "name": "bridge";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "redeemerConfig";
                    "isMut": true;
                    "isSigner": false;
                    "docs": [
                        "Redeemer Config account, which saves program data useful for other",
                        "instructions, specifically for inbound transfers. Also saves the payer",
                        "of the [`initialize`](crate::initialize) instruction as the program's",
                        "owner."
                    ];
                },
                {
                    "name": "wormholeProgram";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Wormhole program."
                    ];
                },
                {
                    "name": "tokenBridgeProgram";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Token Bridge program."
                    ];
                },
                {
                    "name": "tokenBridgeConfig";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Token Bridge config. Token Bridge program needs this account to",
                        "invoke the Wormhole program to post messages. Even though it is a",
                        "required account for redeeming token transfers, it is not actually",
                        "used for completing these transfers."
                    ];
                },
                {
                    "name": "tokenBridgeAuthoritySigner";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "data; it is purely just a signer for SPL tranfers when it is delegated",
                        "spending approval for the SPL token."
                    ];
                },
                {
                    "name": "tokenBridgeCustodySigner";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "data; it is purely just a signer for Token Bridge SPL tranfers."
                    ];
                },
                {
                    "name": "tokenBridgeMintAuthority";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "data; it is purely just a signer (SPL mint authority) for Token Bridge",
                        "wrapped assets."
                    ];
                },
                {
                    "name": "rndrMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rndrEscrow";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "wrndrMint";
                    "isMut": true;
                    "isSigner": false;
                    "docs": [
                        "Token Bridge wrapped mint info. This is the SPL token that will be",
                        "bridged from the foreign contract. The wrapped mint PDA must agree",
                        "with the native token's metadata in the wormhole message. Mutable."
                    ];
                },
                {
                    "name": "wrndrEscrow";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "wormholeBridge";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Wormhole bridge data account (a.k.a. its config)."
                    ];
                },
                {
                    "name": "tokenBridgeEmitter";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "that holds data; it is purely just a signer for posting Wormhole",
                        "messages on behalf of the Token Bridge program."
                    ];
                },
                {
                    "name": "wormholeFeeCollector";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Wormhole fee collector account, which requires lamports before the",
                        "program can post a message (if there is a fee). Token Bridge program",
                        "handles the fee payments."
                    ];
                },
                {
                    "name": "tokenBridgeSequence";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Token Bridge emitter's sequence account. Like with all Wormhole",
                        "emitters, this account keeps track of the sequence number of the last",
                        "posted message."
                    ];
                },
                {
                    "name": "circuitBreaker";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "circuitBreakerProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "associatedTokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "System program."
                    ];
                }
            ];
            "args": [
                {
                    "name": "args";
                    "type": {
                        "defined": "InitializeBridgeArgsV1";
                    };
                }
            ];
        },
        {
            "name": "registerForeignContractV1";
            "accounts": [
                {
                    "name": "owner";
                    "isMut": true;
                    "isSigner": true;
                    "docs": [
                        "Owner of the program set in the [`SenderConfig`] account. Signer for",
                        "creating [`ForeignContract`] account."
                    ];
                },
                {
                    "name": "bridge";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rndrMint";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "wrndrMint";
                    "isMut": true;
                    "isSigner": false;
                    "docs": [
                        "Token Bridge wrapped mint info. This is the SPL token that will be",
                        "bridged from the foreign contract. The wrapped mint PDA must agree",
                        "with the native token's metadata in the wormhole message. Mutable."
                    ];
                },
                {
                    "name": "foreignContract";
                    "isMut": true;
                    "isSigner": false;
                    "docs": [
                        "Foreign Contract account. Create this account if an emitter has not been",
                        "registered yet for this Wormhole chain ID. If there already is a",
                        "contract address saved in this account, overwrite it."
                    ];
                },
                {
                    "name": "tokenBridgeForeignEndpoint";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Token Bridge foreign endpoint. This account should really be one",
                        "endpoint per chain, but Token Bridge's PDA allows for multiple",
                        "endpoints for each chain. We store the proper endpoint for the",
                        "emitter chain."
                    ];
                },
                {
                    "name": "tokenBridgeProgram";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Token Bridge program."
                    ];
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "System program."
                    ];
                }
            ];
            "args": [
                {
                    "name": "args";
                    "type": {
                        "defined": "RegisterForeignContractArgsV1";
                    };
                }
            ];
        },
        {
            "name": "receiveRenderV1";
            "accounts": [
                {
                    "name": "payer";
                    "isMut": true;
                    "isSigner": true;
                    "docs": [
                        "Payer will pay Wormhole fee to transfer tokens"
                    ];
                },
                {
                    "name": "payerTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                    "docs": [
                        "associated token account."
                    ];
                },
                {
                    "name": "config";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Redeemer Config account. Acts as the Token Bridge redeemer, which signs",
                        "for the complete transfer instruction. Read-only."
                    ];
                },
                {
                    "name": "foreignContract";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Foreign Contract account. The registered contract specified in this",
                        "account must agree with the target address for the Token Bridge's token",
                        "transfer. Read-only."
                    ];
                },
                {
                    "name": "bridge";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "wrndrMint";
                    "isMut": true;
                    "isSigner": false;
                    "docs": [
                        "Token Bridge wrapped mint info. This is the SPL token that will be",
                        "bridged from the foreign contract. The wrapped mint PDA must agree",
                        "with the native token's metadata in the wormhole message. Mutable."
                    ];
                },
                {
                    "name": "wrndrEscrow";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "rndrMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rndrEscrow";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "recipientAta";
                    "isMut": true;
                    "isSigner": false;
                    "docs": [
                        "Recipient associated token account."
                    ];
                },
                {
                    "name": "recipient";
                    "isMut": true;
                    "isSigner": false;
                    "docs": [
                        "transaction."
                    ];
                },
                {
                    "name": "wormholeProgram";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Wormhole program."
                    ];
                },
                {
                    "name": "tokenBridgeProgram";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Token Bridge program."
                    ];
                },
                {
                    "name": "tokenBridgeWrappedMeta";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Token Bridge program's wrapped metadata, which stores info",
                        "about the token from its native chain:",
                        "* Wormhole Chain ID",
                        "* Token's native contract address",
                        "* Token's native decimals"
                    ];
                },
                {
                    "name": "tokenBridgeConfig";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Token Bridge config. Read-only."
                    ];
                },
                {
                    "name": "vaa";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Verified Wormhole message account. The Wormhole program verified",
                        "signatures and posted the account data here. Read-only."
                    ];
                },
                {
                    "name": "tokenBridgeClaim";
                    "isMut": true;
                    "isSigner": false;
                    "docs": [
                        "is true if the bridged assets have been claimed. If the transfer has",
                        "not been redeemed, this account will not exist yet."
                    ];
                },
                {
                    "name": "tokenBridgeForeignEndpoint";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Token Bridge foreign endpoint. This account should really be one",
                        "endpoint per chain, but the PDA allows for multiple endpoints for each",
                        "chain! We store the proper endpoint for the emitter chain."
                    ];
                },
                {
                    "name": "tokenBridgeMintAuthority";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "System program."
                    ];
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Token program."
                    ];
                },
                {
                    "name": "associatedTokenProgram";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Associated Token program."
                    ];
                },
                {
                    "name": "rent";
                    "isMut": false;
                    "isSigner": false;
                    "docs": [
                        "Rent sysvar."
                    ];
                },
                {
                    "name": "transfer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "circuitBreaker";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "circuitBreakerProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "args";
                    "type": {
                        "defined": "ReceiveRenderArgsV1";
                    };
                }
            ];
        },
        {
            "name": "updateBridgeV1";
            "accounts": [
                {
                    "name": "bridge";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "authority";
                    "isMut": false;
                    "isSigner": true;
                }
            ];
            "args": [
                {
                    "name": "args";
                    "type": {
                        "defined": "UpdateBridgeArgsV1";
                    };
                }
            ];
        },
        {
            "name": "closeTransferV0";
            "accounts": [
                {
                    "name": "transfer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "bridge";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rndrMint";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "wrndrMint";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "receiver";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "signer";
                    "isMut": true;
                    "isSigner": true;
                }
            ];
            "args": [];
        }
    ];
    "accounts": [
        {
            "name": "redeemerConfig";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "owner";
                        "docs": [
                            "Program's owner."
                        ];
                        "type": "publicKey";
                    },
                    {
                        "name": "bump";
                        "docs": [
                            "PDA bump."
                        ];
                        "type": "u8";
                    },
                    {
                        "name": "tokenBridge";
                        "docs": [
                            "Token Bridge program's relevant addresses."
                        ];
                        "type": {
                            "defined": "InboundTokenBridgeAddresses";
                        };
                    },
                    {
                        "name": "space";
                        "type": {
                            "array": [
                                "u8",
                                128
                            ];
                        };
                    }
                ];
            };
        },
        {
            "name": "foreignContract";
            "docs": [
                "Foreign emitter account data."
            ];
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "chain";
                        "docs": [
                            "Emitter chain. Cannot equal `1` (Solana's Chain ID)."
                        ];
                        "type": "u16";
                    },
                    {
                        "name": "address";
                        "docs": [
                            "Emitter address. Cannot be zero address."
                        ];
                        "type": {
                            "array": [
                                "u8",
                                32
                            ];
                        };
                    },
                    {
                        "name": "tokenBridgeForeignEndpoint";
                        "docs": [
                            "Token Bridge program's foreign endpoint account key."
                        ];
                        "type": "publicKey";
                    },
                    {
                        "name": "space";
                        "type": {
                            "array": [
                                "u8",
                                128
                            ];
                        };
                    }
                ];
            };
        },
        {
            "name": "bridgeV1";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "authority";
                        "type": "publicKey";
                    },
                    {
                        "name": "rndrMint";
                        "type": "publicKey";
                    },
                    {
                        "name": "wrndrMint";
                        "type": "publicKey";
                    },
                    {
                        "name": "incentiveEpoch";
                        "type": "u64";
                    },
                    {
                        "name": "incentiveCounter";
                        "type": "u64";
                    },
                    {
                        "name": "incentiveThreshold";
                        "type": "u64";
                    },
                    {
                        "name": "bump";
                        "type": "u8";
                    },
                    {
                        "name": "space";
                        "type": {
                            "array": [
                                "u8",
                                128
                            ];
                        };
                    }
                ];
            };
        },
        {
            "name": "transferV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "solAddr";
                        "type": "publicKey";
                    },
                    {
                        "name": "sequence";
                        "type": "u64";
                    },
                    {
                        "name": "createdAt";
                        "type": "i64";
                    },
                    {
                        "name": "amount";
                        "type": "u64";
                    },
                    {
                        "name": "incentiveEpoch";
                        "type": "u64";
                    },
                    {
                        "name": "bump";
                        "type": "u8";
                    },
                    {
                        "name": "space";
                        "type": {
                            "array": [
                                "u8",
                                128
                            ];
                        };
                    }
                ];
            };
        }
    ];
    "types": [
        {
            "name": "WindowedCircuitBreakerConfigV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "windowSizeSeconds";
                        "type": "u64";
                    },
                    {
                        "name": "thresholdType";
                        "type": {
                            "defined": "ThresholdType";
                        };
                    },
                    {
                        "name": "threshold";
                        "type": "u64";
                    }
                ];
            };
        },
        {
            "name": "InitializeBridgeArgsV1";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "ethTokenChain";
                        "type": "u16";
                    },
                    {
                        "name": "ethTokenAddress";
                        "type": {
                            "array": [
                                "u8",
                                32
                            ];
                        };
                    },
                    {
                        "name": "config";
                        "type": {
                            "defined": "WindowedCircuitBreakerConfigV0";
                        };
                    },
                    {
                        "name": "incentiveThreshold";
                        "type": "u64";
                    }
                ];
            };
        },
        {
            "name": "ReceiveRenderArgsV1";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "vaaHash";
                        "type": {
                            "array": [
                                "u8",
                                32
                            ];
                        };
                    }
                ];
            };
        },
        {
            "name": "RegisterForeignContractArgsV1";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "chain";
                        "type": "u16";
                    },
                    {
                        "name": "address";
                        "type": {
                            "array": [
                                "u8",
                                32
                            ];
                        };
                    }
                ];
            };
        },
        {
            "name": "UpdateBridgeArgsV1";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "incentiveThreshold";
                        "type": {
                            "option": "u64";
                        };
                    }
                ];
            };
        },
        {
            "name": "InboundTokenBridgeAddresses";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "config";
                        "type": "publicKey";
                    },
                    {
                        "name": "custodySigner";
                        "type": "publicKey";
                    },
                    {
                        "name": "mintAuthority";
                        "type": "publicKey";
                    }
                ];
            };
        },
        {
            "name": "ThresholdType";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "Percent";
                    },
                    {
                        "name": "Absolute";
                    }
                ];
            };
        },
        {
            "name": "BridgeMessage";
            "docs": [
                "Expected message types for this program. Only valid payloads are:",
                "* `Transfer`: Payload ID == 1.",
                "",
                "Payload IDs are encoded as u8."
            ];
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "Transfer";
                        "fields": [
                            {
                                "name": "recipient";
                                "type": {
                                    "array": [
                                        "u8",
                                        32
                                    ];
                                };
                            }
                        ];
                    }
                ];
            };
        }
    ];
    "errors": [
        {
            "code": 6000;
            "name": "InvalidWormholeBridge";
            "msg": "InvalidWormholeBridge";
        },
        {
            "code": 6001;
            "name": "InvalidWormholeFeeCollector";
            "msg": "InvalidWormholeFeeCollector";
        },
        {
            "code": 6002;
            "name": "InvalidWormholeEmitter";
            "msg": "InvalidWormholeEmitter";
        },
        {
            "code": 6003;
            "name": "InvalidWormholeSequence";
            "msg": "InvalidWormholeSequence";
        },
        {
            "code": 6004;
            "name": "InvalidSysvar";
            "msg": "InvalidSysvar";
        },
        {
            "code": 6005;
            "name": "OwnerOnly";
            "msg": "OwnerOnly";
        },
        {
            "code": 6006;
            "name": "BumpNotFound";
            "msg": "BumpNotFound";
        },
        {
            "code": 6007;
            "name": "InvalidForeignContract";
            "msg": "InvalidForeignContract";
        },
        {
            "code": 6008;
            "name": "ZeroBridgeAmount";
            "msg": "ZeroBridgeAmount";
        },
        {
            "code": 6009;
            "name": "InvalidTokenBridgeConfig";
            "msg": "InvalidTokenBridgeConfig";
        },
        {
            "code": 6010;
            "name": "InvalidTokenBridgeAuthoritySigner";
            "msg": "InvalidTokenBridgeAuthoritySigner";
        },
        {
            "code": 6011;
            "name": "InvalidTokenBridgeCustodySigner";
            "msg": "InvalidTokenBridgeCustodySigner";
        },
        {
            "code": 6012;
            "name": "InvalidTokenBridgeEmitter";
            "msg": "InvalidTokenBridgeEmitter";
        },
        {
            "code": 6013;
            "name": "InvalidTokenBridgeSequence";
            "msg": "InvalidTokenBridgeSequence";
        },
        {
            "code": 6014;
            "name": "InvalidTokenBridgeSender";
            "msg": "InvalidTokenBridgeSender";
        },
        {
            "code": 6015;
            "name": "InvalidRecipient";
            "msg": "InvalidRecipient";
        },
        {
            "code": 6016;
            "name": "InvalidTransferTokenAccount";
            "msg": "InvalidTransferTokenAccount";
        },
        {
            "code": 6017;
            "name": "InvalidTransferToChain";
            "msg": "InvalidTransferTokenChain";
        },
        {
            "code": 6018;
            "name": "InvalidTransferTokenChain";
            "msg": "InvalidTransferTokenChain";
        },
        {
            "code": 6019;
            "name": "InvalidPayerAta";
            "msg": "InvalidPayerAta";
        },
        {
            "code": 6020;
            "name": "InvalidTransferToAddress";
            "msg": "InvalidTransferToAddress";
        },
        {
            "code": 6021;
            "name": "AlreadyRedeemed";
            "msg": "AlreadyRedeemed";
        },
        {
            "code": 6022;
            "name": "InvalidTokenBridgeForeignEndpoint";
            "msg": "InvalidTokenBridgeForeignEndpoint";
        },
        {
            "code": 6023;
            "name": "NonExistentRelayerAta";
            "msg": "NonExistentRelayerAta";
        },
        {
            "code": 6024;
            "name": "InvalidTokenBridgeMintAuthority";
            "msg": "InvalidTokenBridgeMintAuthority";
        },
        {
            "code": 6025;
            "name": "ReceiveAmountTooLarge";
            "msg": "ReceiveAmountTooLarge";
        }
    ];
};
export declare const IDL: Bridge;
//# sourceMappingURL=bridge.d.ts.map